@@ -63,29 +63,32 @@ def prompt_for_password(prompt=None):
             pass
     # No password because we did't have a tty or nothing was entered
     if not pw:
-        raise exc.CommandError(_("No password entered, or found via"
-                                 " --os-password or OS_PASSWORD"),)
+        raise exc.CommandError(
+            _(
+                "No password entered, or found via"
+                " --os-password or OS_PASSWORD"
+            ),
+        )
 
     return pw
 
 
 class OpenStackShell(app.App):
-
     CONSOLE_MESSAGE_FORMAT = '%(levelname)s: %(name)s %(message)s'
 
     log = logging.getLogger(__name__)
     timing_data = []
 
     def __init__(
-            self,
-            description=None,
-            version=None,
-            command_manager=None,
-            stdin=None,
-            stdout=None,
-            stderr=None,
-            interactive_app_factory=None,
-            deferred_help=False,
+        self,
+        description=None,
+        version=None,
+        command_manager=None,
+        stdin=None,
+        stdout=None,
+        stderr=None,
+        interactive_app_factory=None,
+        deferred_help=False,
     ):
         # Patch command.Command to add a default auth_required = True
         command.Command.auth_required = True
@@ -104,7 +107,7 @@ class OpenStackShell(app.App):
         else:
             cm = command_manager
 
-        super(OpenStackShell, self).__init__(
+        super().__init__(
             description=__doc__.strip(),
             version=version,
             command_manager=cm,
@@ -131,7 +134,7 @@ class OpenStackShell(app.App):
         ret_val = 1
         self.command_options = argv
         try:
-            ret_val = super(OpenStackShell, self).run(argv)
+            ret_val = super().run(argv)
             return ret_val
         except Exception as e:
             if not logging.getLogger('').handlers:
@@ -144,7 +147,7 @@ class OpenStackShell(app.App):
             return ret_val
 
         finally:
-            self.log.info("END return value: %s", ret_val)
+            self.log.debug("END return value: %s", ret_val)
 
     def init_profile(self):
         self.do_profile = osprofiler_profiler and self.options.profile
@@ -162,16 +165,19 @@ class OpenStackShell(app.App):
             # printed. In fact we can define custom log level here with value
             # bigger than most big default one (CRITICAL) or something like
             # that (PROFILE = 60 for instance), but not sure we need it here.
-            self.log.warning("Trace ID: %s" % trace_id)
-            self.log.warning("Short trace ID "
-                             "for OpenTracing-based drivers: %s" % short_id)
-            self.log.warning("Display trace data with command:\n"
-                             "osprofiler trace show --html %s " % trace_id)
+            self.log.warning(f"Trace ID: {trace_id}")
+            self.log.warning(
+                "Short trace ID " f"for OpenTracing-based drivers: {short_id}"
+            )
+            self.log.warning(
+                "Display trace data with command:\n"
+                f"osprofiler trace show --html {trace_id} "
+            )
 
     def run_subcommand(self, argv):
         self.init_profile()
         try:
-            ret_value = super(OpenStackShell, self).run_subcommand(argv)
+            ret_value = super().run_subcommand(argv)
         finally:
             self.close_profile()
         return ret_value
@@ -179,15 +185,13 @@ class OpenStackShell(app.App):
     def interact(self):
         self.init_profile()
         try:
-            ret_value = super(OpenStackShell, self).interact()
+            ret_value = super().interact()
         finally:
             self.close_profile()
         return ret_value
 
     def build_option_parser(self, description, version):
-        parser = super(OpenStackShell, self).build_option_parser(
-            description,
-            version)
+        parser = super().build_option_parser(description, version)
 
         # service token auth argument
         parser.add_argument(
@@ -243,32 +247,38 @@ class OpenStackShell(app.App):
             '--os-default-domain',
             metavar='<auth-domain>',
             dest='default_domain',
-            default=utils.env(
-                'OS_DEFAULT_DOMAIN',
-                default=DEFAULT_DOMAIN),
-            help=_('Default domain ID, default=%s. '
-                   '(Env: OS_DEFAULT_DOMAIN)') % DEFAULT_DOMAIN,
+            default=utils.env('OS_DEFAULT_DOMAIN', default=DEFAULT_DOMAIN),
+            help=_(
+                'Default domain ID, default=%s. ' '(Env: OS_DEFAULT_DOMAIN)'
+            )
+            % DEFAULT_DOMAIN,
         )
         parser.add_argument(
             '--os-interface',
             metavar='<interface>',
             dest='interface',
             choices=['admin', 'public', 'internal'],
-            default=utils.env(
-                'OS_INTERFACE',
-                default=DEFAULT_INTERFACE),
-            help=_('Select an interface type.'
-                   ' Valid interface types: [admin, public, internal].'
-                   ' default=%s, (Env: OS_INTERFACE)') % DEFAULT_INTERFACE,
+            # do not set default value inside utils.env() else user's cloud
+            # config key 'interface' will be ignored. Use OSC_Config's ctor
+            # option 'override_defaults' below instead.
+            default=utils.env('OS_INTERFACE'),
+            help=_(
+                'Select an interface type.'
+                ' Valid interface types: [admin, public, internal].'
+                ' default=%s, (Env: OS_INTERFACE)'
+            )
+            % DEFAULT_INTERFACE,
         )
         parser.add_argument(
             '--os-service-provider',
             metavar='<service_provider>',
             dest='service_provider',
             default=utils.env('OS_SERVICE_PROVIDER'),
-            help=_('Authenticate with and perform the command on a service'
-                   ' provider using Keystone-to-keystone federation. Must'
-                   ' also specify the remote project option.')
+            help=_(
+                'Authenticate with and perform the command on a service'
+                ' provider using Keystone-to-keystone federation. Must'
+                ' also specify the remote project option.'
+            ),
         )
         remote_project_group = parser.add_mutually_exclusive_group()
         remote_project_group.add_argument(
@@ -276,16 +286,20 @@ class OpenStackShell(app.App):
             metavar='<remote_project_name>',
             dest='remote_project_name',
             default=utils.env('OS_REMOTE_PROJECT_NAME'),
-            help=_('Project name when authenticating to a service provider'
-                   ' if using Keystone-to-Keystone federation.')
+            help=_(
+                'Project name when authenticating to a service provider'
+                ' if using Keystone-to-Keystone federation.'
+            ),
         )
         remote_project_group.add_argument(
             '--os-remote-project-id',
             metavar='<remote_project_id>',
             dest='remote_project_id',
             default=utils.env('OS_REMOTE_PROJECT_ID'),
-            help=_('Project ID when authenticating to a service provider'
-                   ' if using Keystone-to-Keystone federation.')
+            help=_(
+                'Project ID when authenticating to a service provider'
+                ' if using Keystone-to-Keystone federation.'
+            ),
         )
         remote_project_domain_group = parser.add_mutually_exclusive_group()
         remote_project_domain_group.add_argument(
@@ -293,18 +307,22 @@ class OpenStackShell(app.App):
             metavar='<remote_project_domain_name>',
             dest='remote_project_domain_name',
             default=utils.env('OS_REMOTE_PROJECT_DOMAIN_NAME'),
-            help=_('Domain name of the project when authenticating to a'
-                   ' service provider if using Keystone-to-Keystone'
-                   ' federation.')
+            help=_(
+                'Domain name of the project when authenticating to a'
+                ' service provider if using Keystone-to-Keystone'
+                ' federation.'
+            ),
         )
         remote_project_domain_group.add_argument(
             '--os-remote-project-domain-id',
             metavar='<remote_project_domain_id>',
             dest='remote_project_domain_id',
             default=utils.env('OS_REMOTE_PROJECT_DOMAIN_ID'),
-            help=_('Domain ID of the project when authenticating to a'
-                   ' service provider if using Keystone-to-Keystone'
-                   ' federation.')
+            help=_(
+                'Domain ID of the project when authenticating to a'
+                ' service provider if using Keystone-to-Keystone'
+                ' federation.'
+            ),
         )
         parser.add_argument(
             '--timing',
@@ -344,6 +362,7 @@ class OpenStackShell(app.App):
     * ClientManager
 
     """
+
     def _final_defaults(self):
         # Set the default plugin to None
         # NOTE(dtroyer): This is here to set up for setting it to a default
@@ -394,11 +413,12 @@ class OpenStackShell(app.App):
         """
 
         # Parent __init__ parses argv into self.options
-        super(OpenStackShell, self).initialize_app(argv)
-        self.log.info("START with options: %s",
-                      strutils.mask_password(" ".join(self.command_options)))
-        self.log.debug("options: %s",
-                       strutils.mask_password(self.options))
+        super().initialize_app(argv)
+        self.log.info(
+            "START with options: %s",
+            strutils.mask_password(" ".join(self.command_options)),
+        )
+        self.log.debug("options: %s", strutils.mask_password(self.options))
 
         # Callout for stuff between superclass init and o-c-c
         self._final_defaults()
@@ -408,11 +428,11 @@ class OpenStackShell(app.App):
             self.cloud_config = cloud_config.OSC_Config(
                 pw_func=prompt_for_password,
                 override_defaults={
-                    'interface': None,
+                    'interface': DEFAULT_INTERFACE,
                     'auth_type': self._auth_type,
                 },
             )
-        except (IOError, OSError) as e:
+        except OSError as e:
             self.log.critical("Could not read clouds.yaml configuration file")
             self.print_help_if_requested()
             raise e
@@ -433,8 +453,9 @@ class OpenStackShell(app.App):
         self.log_configurator.configure(self.cloud)
         self.dump_stack_trace = self.log_configurator.dump_trace
         self.log.debug("defaults: %s", self.cloud_config.defaults)
-        self.log.debug("cloud cfg: %s",
-                       strutils.mask_password(self.cloud.config))
+        self.log.debug(
+            "cloud cfg: %s", strutils.mask_password(self.cloud.config)
+        )
 
         # Callout for stuff between o-c-c and ClientManager
         # self._initialize_app_2(self.options)
@@ -454,7 +475,7 @@ class OpenStackShell(app.App):
 
     def prepare_to_run_command(self, cmd):
         """Set up auth and API versions"""
-        self.log.info(
+        self.log.debug(
             'command: %s -> %s.%s (auth=%s)',
             getattr(cmd, 'cmd_name', '<none>'),
             cmd.__class__.__module__,
@@ -488,8 +509,9 @@ class OpenStackShell(app.App):
                 # let the command decide whether we need a scoped token
                 self.client_manager.validate_scope()
             # Trigger the Identity client to initialize
-            self.client_manager.session.auth.auth_ref = \
+            self.client_manager.session.auth.auth_ref = (
                 self.client_manager.auth_ref
+            )
         return
 
     def clean_up(self, cmd, result, err):
@@ -517,8 +539,10 @@ class OpenStackShell(app.App):
             # If anything other than prettytable is specified, force csv
             format = 'table'
             # Check the formatter used in the actual command
-            if hasattr(cmd, 'formatter') \
-                    and cmd.formatter != cmd._formatter_plugins['table'].obj:
+            if (
+                hasattr(cmd, 'formatter')
+                and cmd.formatter != cmd._formatter_plugins['table'].obj
+            ):
                 format = 'csv'
 
             sys.stdout.write('\n')
