@@ -13,7 +13,8 @@
 #   under the License.
 
 import argparse
-import mock
+import sys
+from unittest import mock
 
 from osc_lib.tests import utils as test_utils
 from osc_lib.utils import tags
@@ -25,42 +26,61 @@ def help_enhancer(_h):
 
 
 class TestTags(test_utils.TestCase):
-
     def test_add_tag_filtering_option_to_parser(self):
         parser = argparse.ArgumentParser()
         tags.add_tag_filtering_option_to_parser(parser, 'test')
 
-        parsed_args = parser.parse_args(['--tags', 'tag1,tag2',
-                                         '--any-tags', 'tag4',
-                                         '--not-tags', 'tag5',
-                                         '--not-any-tags', 'tag6'])
+        parsed_args = parser.parse_args(
+            [
+                '--tags',
+                'tag1,tag2',
+                '--any-tags',
+                'tag4',
+                '--not-tags',
+                'tag5',
+                '--not-any-tags',
+                'tag6',
+            ]
+        )
 
         actual = getattr(parsed_args, 'tags', [])
         expected = ['tag1', 'tag2']
-        self.assertItemsEqual(expected, actual)
+        self.assertCountEqual(expected, actual)
 
         actual = getattr(parsed_args, 'any_tags', [])
         expected = ['tag4']
-        self.assertItemsEqual(expected, actual)
+        self.assertCountEqual(expected, actual)
 
         actual = getattr(parsed_args, 'not_tags', [])
         expected = ['tag5']
-        self.assertItemsEqual(expected, actual)
+        self.assertCountEqual(expected, actual)
 
         actual = getattr(parsed_args, 'not_any_tags', [])
         expected = ['tag6']
-        self.assertItemsEqual(expected, actual)
+        self.assertCountEqual(expected, actual)
 
     def test_get_tag_filtering_args(self):
         parser = argparse.ArgumentParser()
         tags.add_tag_filtering_option_to_parser(parser, 'test')
 
-        parsed_args = parser.parse_args(['--tags', 'tag1,tag2',
-                                         '--any-tags', 'tag4',
-                                         '--not-tags', 'tag5',
-                                         '--not-any-tags', 'tag6'])
-        expected = {'tags': 'tag1,tag2', 'any_tags': 'tag4',
-                    'not_tags': 'tag5', 'not_any_tags': 'tag6'}
+        parsed_args = parser.parse_args(
+            [
+                '--tags',
+                'tag1,tag2',
+                '--any-tags',
+                'tag4',
+                '--not-tags',
+                'tag5',
+                '--not-any-tags',
+                'tag6',
+            ]
+        )
+        expected = {
+            'tags': 'tag1,tag2',
+            'any_tags': 'tag4',
+            'not_tags': 'tag5',
+            'not_any_tags': 'tag6',
+        }
         args = {}
         tags.get_tag_filtering_args(parsed_args, args)
         self.assertEqual(expected, args)
@@ -70,18 +90,19 @@ class TestTags(test_utils.TestCase):
         tags.add_tag_option_to_parser_for_create(parser, 'test')
 
         # Test that --tag and --no-tag are mutually exclusive
-        self.assertRaises(SystemExit, parser.parse_args,
-                          ['--tag', 'tag1', '--no-tag'])
+        self.assertRaises(
+            SystemExit, parser.parse_args, ['--tag', 'tag1', '--no-tag']
+        )
 
         parsed_args = parser.parse_args(['--tag', 'tag1'])
         actual = getattr(parsed_args, 'tags', [])
         expected = ['tag1']
-        self.assertItemsEqual(expected, actual)
+        self.assertCountEqual(expected, actual)
 
         parsed_args = parser.parse_args(['--no-tag'])
         actual = getattr(parsed_args, 'no-tag', [])
         expected = []
-        self.assertItemsEqual(expected, actual)
+        self.assertCountEqual(expected, actual)
 
     def test_add_tag_option_to_parser_for_set(self):
         parser = argparse.ArgumentParser()
@@ -90,30 +111,31 @@ class TestTags(test_utils.TestCase):
         parsed_args = parser.parse_args(['--tag', 'tag1'])
         actual = getattr(parsed_args, 'tags', [])
         expected = ['tag1']
-        self.assertItemsEqual(expected, actual)
+        self.assertCountEqual(expected, actual)
 
         parsed_args = parser.parse_args(['--no-tag'])
         actual = getattr(parsed_args, 'no-tag', [])
         expected = []
-        self.assertItemsEqual(expected, actual)
+        self.assertCountEqual(expected, actual)
 
     def test_add_tag_option_to_parser_for_unset(self):
         parser = argparse.ArgumentParser()
         tags.add_tag_option_to_parser_for_unset(parser, 'test')
 
         # Test that --tag and --all-tag are mutually exclusive
-        self.assertRaises(SystemExit, parser.parse_args,
-                          ['--tag', 'tag1', '--all-tag'])
+        self.assertRaises(
+            SystemExit, parser.parse_args, ['--tag', 'tag1', '--all-tag']
+        )
 
         parsed_args = parser.parse_args(['--tag', 'tag1'])
         actual = getattr(parsed_args, 'tags', [])
         expected = ['tag1']
-        self.assertItemsEqual(expected, actual)
+        self.assertCountEqual(expected, actual)
 
         parsed_args = parser.parse_args(['--all-tag'])
         actual = getattr(parsed_args, 'all-tag', [])
         expected = []
-        self.assertItemsEqual(expected, actual)
+        self.assertCountEqual(expected, actual)
 
     def test_update_tags_for_set(self):
         mock_client = mock.MagicMock()
@@ -126,7 +148,8 @@ class TestTags(test_utils.TestCase):
         mock_obj.tags = None
         tags.update_tags_for_set(mock_client, mock_obj, mock_parsed_args)
         mock_client.set_tags.assert_called_once_with(
-            mock_obj, list(mock_parsed_args.tags))
+            mock_obj, list(mock_parsed_args.tags)
+        )
 
         # no-tag False path
         mock_client.set_tags.reset_mock()
@@ -135,8 +158,7 @@ class TestTags(test_utils.TestCase):
         mock_obj.tags = ['tag2']
         expected_list = ['tag1', 'tag2']
         tags.update_tags_for_set(mock_client, mock_obj, mock_parsed_args)
-        mock_client.set_tags.assert_called_once_with(
-            mock_obj, expected_list)
+        mock_client.set_tags.assert_called_once_with(mock_obj, expected_list)
 
         # no new tags path
         mock_client.set_tags.reset_mock()
@@ -163,8 +185,7 @@ class TestTags(test_utils.TestCase):
         mock_parsed_args.all_tag = True
         mock_parsed_args.tags = None
         tags.update_tags_for_unset(mock_client, mock_obj, mock_parsed_args)
-        mock_client.set_tags.assert_called_once_with(
-            mock_obj, [])
+        mock_client.set_tags.assert_called_once_with(mock_obj, [])
 
         # Remove one tag
         mock_client.set_tags.reset_mock()
@@ -172,12 +193,10 @@ class TestTags(test_utils.TestCase):
         mock_parsed_args.all_tag = False
         mock_parsed_args.tags = ['tag2']
         tags.update_tags_for_unset(mock_client, mock_obj, mock_parsed_args)
-        mock_client.set_tags.assert_called_once_with(
-            mock_obj, ['tag1'])
+        mock_client.set_tags.assert_called_once_with(mock_obj, ['tag1'])
 
 
 class TestTagHelps(test_utils.TestCase):
-
     def _test_tag_method_help(self, meth, exp_normal, exp_enhanced):
         """Vet the help text of the options added by the tag filtering helpers.
 
@@ -186,13 +205,17 @@ class TestTagHelps(test_utils.TestCase):
         :param exp_enhanced: Expected output with ``enhance_help`` set to
             ``help_enhancer``
         """
+        if sys.version_info >= (3, 10):
+            options_name = 'options'
+        else:
+            options_name = 'optional arguments'
         parser = argparse.ArgumentParser()
         meth(parser, 'test')
-        self.assertEqual(exp_normal, parser.format_help())
+        self.assertEqual(exp_normal % options_name, parser.format_help())
 
         parser = argparse.ArgumentParser()
         meth(parser, 'test', enhance_help=help_enhancer)
-        self.assertEqual(exp_enhanced, parser.format_help())
+        self.assertEqual(exp_enhanced % options_name, parser.format_help())
 
     def test_add_tag_filtering_option_to_parser(self):
         self._test_tag_method_help(
@@ -202,7 +225,7 @@ usage: run.py [-h] [--tags <tag>[,<tag>,...]] [--any-tags <tag>[,<tag>,...]]
               [--not-tags <tag>[,<tag>,...]]
               [--not-any-tags <tag>[,<tag>,...]]
 
-optional arguments:
+%s:
   -h, --help            show this help message and exit
   --tags <tag>[,<tag>,...]
                         List test which have all given tag(s) (Comma-separated
@@ -222,7 +245,7 @@ usage: run.py [-h] [--tags <tag>[,<tag>,...]] [--any-tags <tag>[,<tag>,...]]
               [--not-tags <tag>[,<tag>,...]]
               [--not-any-tags <tag>[,<tag>,...]]
 
-optional arguments:
+%s:
   -h, --help            show this help message and exit
   --tags <tag>[,<tag>,...]
                         )sgat fo tsil detarapes-ammoC( )s(gat nevig lla evah
@@ -236,7 +259,8 @@ optional arguments:
   --not-any-tags <tag>[,<tag>,...]
                         )sgat fo tsil detarapes-ammoC( )s(gat nevig yna evah
                         hcihw tset edulcxE
-""")
+""",
+        )
 
     def test_add_tag_option_to_parser_for_create(self):
         self._test_tag_method_help(
@@ -244,7 +268,7 @@ optional arguments:
             """\
 usage: run.py [-h] [--tag <tag> | --no-tag]
 
-optional arguments:
+%s:
   -h, --help   show this help message and exit
   --tag <tag>  Tag to be added to the test (repeat option to set multiple
                tags)
@@ -253,12 +277,13 @@ optional arguments:
             """\
 usage: run.py [-h] [--tag <tag> | --no-tag]
 
-optional arguments:
+%s:
   -h, --help   show this help message and exit
   --tag <tag>  )sgat elpitlum tes ot noitpo taeper( tset eht ot dedda eb ot
                gaT
   --no-tag     tset eht htiw detaicossa sgat oN
-""")
+""",
+        )
 
     def test_add_tag_option_to_parser_for_set(self):
         self._test_tag_method_help(
@@ -266,7 +291,7 @@ optional arguments:
             """\
 usage: run.py [-h] [--tag <tag>] [--no-tag]
 
-optional arguments:
+%s:
   -h, --help   show this help message and exit
   --tag <tag>  Tag to be added to the test (repeat option to set multiple
                tags)
@@ -276,13 +301,14 @@ optional arguments:
             """\
 usage: run.py [-h] [--tag <tag>] [--no-tag]
 
-optional arguments:
+%s:
   -h, --help   show this help message and exit
   --tag <tag>  )sgat elpitlum tes ot noitpo taeper( tset eht ot dedda eb ot
                gaT
   --no-tag     sgat tnerruc etirwrevo ot gat-on-- dna gat-- htob yficepS .tset
                eht htiw detaicossa sgat raelC
-""")
+""",
+        )
 
     def test_add_tag_option_to_parser_for_unset(self):
         self._test_tag_method_help(
@@ -290,7 +316,7 @@ optional arguments:
             """\
 usage: run.py [-h] [--tag <tag> | --all-tag]
 
-optional arguments:
+%s:
   -h, --help   show this help message and exit
   --tag <tag>  Tag to be removed from the test (repeat option to remove
                multiple tags)
@@ -299,9 +325,10 @@ optional arguments:
             """\
 usage: run.py [-h] [--tag <tag> | --all-tag]
 
-optional arguments:
+%s:
   -h, --help   show this help message and exit
   --tag <tag>  )sgat elpitlum evomer ot noitpo taeper( tset eht morf devomer
                eb ot gaT
   --all-tag    tset eht htiw detaicossa sgat lla raelC
-""")
+""",
+        )
